.. mdinclude:: ../README.md

Tables of contents and indices
------------------------------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples_and_usage
   api
   license
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
